@@ -1,4 +1,4 @@
-# Copyright (C) 2008 Osmo Salomaa
+# Copyright (C) 2008-2009 Osmo Salomaa
 #
 # This file is part of NFO Viewer.
 #
@@ -14,19 +14,22 @@
 # You should have received a copy of the GNU General Public License along with
 # NFO Viewer. If not, see <http://www.gnu.org/licenses/>.
 
+"""Spawning, managing and killing viewer windows.
+
+:var windows: List of existing :class:`nfoview.Window` instances
+"""
+
 import gtk
 import nfoview
 import os
 
 windows = []
 
-def _on_window_delete_event(window, event):
-    """Exit the GTK main loop if the last window was closed."""
 
+def _on_window_delete_event(window, event):
+    """Exit the ``GTK+`` main loop if the last window was closed."""
     window.destroy()
-    ids = map(id, windows)
-    index = ids.index(id(window))
-    windows.pop(index)
+    windows.remove(window)
     if windows: return
     nfoview.conf.write_to_file()
     try: gtk.main_quit()
@@ -35,21 +38,19 @@ def _on_window_delete_event(window, event):
 
 def open_window(path=None):
     """Open file in a new window and present that window."""
-
     window = nfoview.Window(path)
-    callback = _on_window_delete_event
-    window.connect("delete-event", callback)
+    window.connect("delete-event",
+                   _on_window_delete_event)
+
     windows.append(window)
     window.present()
 
 def main(args):
-    """Start viewer windows for given arguments."""
-
-    for path in filter(os.path.isfile, args):
+    """Start viewer windows for files given as arguments."""
+    for path in sorted(filter(os.path.isfile, args)):
         open_window(path)
     if not windows:
-        # If no arguments were given,
-        # or none of them exist,
+        # If no arguments were given, or none of them exist,
         # open one blank window.
         open_window()
     gtk.main()
