@@ -14,35 +14,29 @@
 # You should have received a copy of the GNU General Public License along with
 # NFO Viewer. If not, see <http://www.gnu.org/licenses/>.
 
+import gtk
 import nfoview
-import os
 
 
 class TestBuilderDialog(nfoview.TestCase):
 
     def setup_method(self, method):
-
-        path = os.path.join(nfoview.DATA_DIR, "preferences-dialog.ui")
-        self.dialog = nfoview.BuilderDialog(path)
+        self.dialog = nfoview.PreferencesDialog(gtk.Window())
         self.dialog.show()
 
     def test___getattr__(self):
-
         self.dialog.hide()
         self.dialog.show()
 
     def test___init__(self):
-
         assert hasattr(self.dialog, "_builder")
         assert hasattr(self.dialog, "_dialog")
 
     def test___setattr__(self):
-
         self.dialog.props.visible = False
         self.dialog.props.visible = True
         self.dialog.props.visible = False
 
     def test_run(self):
-
         self.dialog._dialog.run = lambda: None
         self.dialog.run()
